==> Flask-LazyViews-0.5.1.tar.gz: Flask-LazyViews-0.5.1/setup.py <==
#!/usr/bin/env python

import os
import re

from setuptools import setup


DIRNAME = os.path.dirname(__file__)
rel = lambda *parts: os.path.abspath(os.path.join(DIRNAME, *parts))

README = open(rel('README.rst')).read()
INIT_PY = open(rel('flask_lazyviews', '__init__.py')).read()
VERSION = re.findall("__version__ = '([^']+)'", INIT_PY)[0]


setup(
    name='Flask-LazyViews',
    version=VERSION,
    description='Registering url routes for Flask app and blueprints in lazy '
                'way.',
    long_description=README,
    author='Igor Davydenko',
    author_email='playpauseandstop@gmail.com',
    url='https://github.com/playpauseandstop/Flask-LazyViews',
    install_requires=[
        'Flask',
    ],
    packages=[
        'flask_lazyviews',
    ],
    platforms='any',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Operating System :: OS Independent',
        'Topic :: Utilities',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: BSD License',
    ],
    keywords='flask lazy views',
    license='BSD License',
)

==> Flask-LazyViews-0.6.tar.gz: Flask-LazyViews-0.6/setup.py <==
#!/usr/bin/env python

import os
import re

from setuptools import setup


DIRNAME = os.path.dirname(__file__)
rel = lambda *parts: os.path.abspath(os.path.join(DIRNAME, *parts))

README = open(rel('README.rst')).read()
INIT_PY = open(rel('flask_lazyviews', '__init__.py')).read()
VERSION = re.findall("__version__ = '([^']+)'", INIT_PY)[0]


setup(
    name='Flask-LazyViews',
    version=VERSION,
    description='Registers URL routes for Flask application or blueprint in '
                'lazy way.',
    long_description=README,
    author='Igor Davydenko',
    author_email='playpauseandstop@gmail.com',
    url='https://github.com/playpauseandstop/Flask-LazyViews',
    install_requires=[
        'Flask>=0.8',
    ],
    packages=[
        'flask_lazyviews',
    ],
    platforms='any',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Operating System :: OS Independent',
        'Topic :: Utilities',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: BSD License',
    ],
    keywords='flask lazy views',
    license='BSD License',
)
